@@ -4,135 +4,140 @@ use Datahub::Factory::Sane;
 
 use parent 'Datahub::Factory::Cmd';
 
-use Moo;
 use Module::Load;
 use Catmandu;
-use Catmandu::Util qw(data_at is_instance);
+use Catmandu::Util qw(data_at);
 use Datahub::Factory;
 use namespace::clean;
-use Datahub::Factory::Pipeline;
+use Datahub::Factory::PipelineConfig;
 use Datahub::Factory::Fixer::Condition;
 
-with 'Datahub::Factory::Flash';
+use Data::Dumper qw(Dumper);
 
-sub abstract {
-    "Transport data from a data source to a data sink."
-}
+sub abstract { "Transport data from a data source to a datahub instance" }
 
-sub description {
-    "Transport data from a data source to a data sink using pipeline configurations."
-}
+sub description { "Long description on blortex algorithm" }
 
 sub opt_spec {
-    return (
-        [ "pipeline|p=s", "Location of the pipeline configuration file"],
-        [ "verbose|v", "Verbose output"]
-    );
+	return (
+		[ "pipeline|p=s", "Location of the pipeline configuration file"]
+	);
 }
 
 sub validate_args {
-    my ($self, $opt, $args) = @_;
+	my ($self, $opt, $args) = @_;
 
     if (! $opt->{'pipeline'}) {
         $self->usage_error('The --pipeline flag is required.');
     }
 
-    # no args allowed but options!
-    $self->usage_error("No args allowed") if @$args;
+	my $pcfg = Datahub::Factory->pipeline($opt);
+    try {
+        $pcfg->check_object();
+    } catch {
+        $self->usage_error($_);
+    }
+	# no args allowed but options!
+	$self->usage_error("No args allowed") if @$args;
 }
 
 sub execute {
-    my ($self, $opt, $args) = @_;
+  my ($self, $arguments, $args) = @_;
 
-    # Get a logger
-    my $logger = Datahub::Factory->log;
+  my $logger = Datahub::Factory->log;
 
-    # Enable verbosity based on -v flag
-    $self->verbose($opt->{verbose});
+  my ($pcfg, $opt);
+  try {
+      $pcfg = Datahub::Factory->pipeline($arguments);
+      $opt = $pcfg->opt;
+  } catch {
+      $logger->fatal($_);
+      exit 1;
+  };
 
-    # Load the configuration
-    # @todo
-    #    Validation of the pipeline configuration happens here. Throw and catch
-    #    nice errors.
-    $self->info("Loading pipeline configuration...");
-    my ($pipeline, $options);
-    $pipeline = Datahub::Factory->pipeline($opt->{pipeline});
-    $options = $pipeline->parse();
+  # Load modules
+  my ($import_module, $fix_module, $export_module);
+  try {
+      $import_module = Datahub::Factory->importer($opt->{importer})->new($opt->{oimport});
+  } catch {
+      $logger->fatal(sprintf('%s at [plugin_importer_%s]', $_, $opt->{'importer'}));
+      exit 1;
+  };
+  try {
+      $export_module = Datahub::Factory->exporter($opt->{exporter})->new($opt->{oexport});
+  } catch {
+      $logger->fatal(sprintf('%s at [plugin_exporter_%s]', $_, $opt->{'exporter'}));
+      exit 1;
+  };
 
-    # Load modules
-    $self->info("Initializing importer/exporter...");
-    my ($import_module, $fix_module, $export_module);
-    $import_module = Datahub::Factory
-        ->importer($options->{importer}->{name})
-        ->new($options->{importer}->{options});
-    $export_module = Datahub::Factory
-        ->exporter($options->{exporter}->{name})
-        ->new($options->{exporter}->{options});
+  # Perform import/fix/export
 
-    # Load conditions & fixers
-    $self->info("Initializing fixers...");
-    my $condition = Datahub::Factory::Fixer::Condition->new('fixer' => $options->{fixer});
-    my $fixers = $condition->get_fixers();
-
-    my $counter = 0;
-
-    # Import data and start processing
-    $self->info("Importing data from source...");
-    $import_module->each(sub {
-        my $item = shift;
-        my ($msg, $item_id);
-
-        $counter++;
-
-        # We use an extra try/catch block here to catch non-fatal errors. If we
-        # didn't, errors thrown by the Catmandu modules would be caught by the
-        # catch block in CLI.pm and break the processing. Errors caused by
-        # dirty data should skip the processing of a particular record.
-        if (try {
-            $item_id = data_at($options->{'id_path'}, $item);
-            $item_id //= 'Undefined ID';
-
-            $fix_module = $condition->fix_module($fixers, $item);
-            $fix_module->fixer->fix($item);
-            $export_module->add($item);
-
-            $msg = sprintf('Item #%s : %s (id): exported.', $counter, $item_id);
-            $self->success($msg);
-            $logger->info($msg);
-        } catch {
-            my $error = ($_->can('message')) ? $_->message : $_;
-
-            # Determine if we should skip, or halt the processing entirely.
-            # Depends on the type of Exception which bubbles up.
-            if (is_instance $_, 'Catmandu::BadVal') {
-                $msg = sprintf('Item %d (counted): could not execute fix: %s', $counter, $error);
-                $self->error($msg);
-                $logger->error($msg);
-                return 1;
-            }
-            elsif (is_instance $_, 'Datahub::Factory::InvalidPipeline') {
-                # Throw a fatal error if the pipeline configuration was invalid
-                $self->error($msg);
-                $logger->fatal($error);
+  # Catmandu::Fix treats all warnings as fatal errors (this is good)
+  # so we can catch them with try-catch
+  # Not that errors here are _not_ fatal => continue running
+  # till all records have been processed
+  my $counter = 0;
+  $import_module->importer->each(sub {
+      my $item = shift;
+      $counter++;
+      my $f = try {
+          try {
+                my $cond = Datahub::Factory::Fixer::Condition->new(
+                    'options' => $opt,
+                    'item'    => $item
+                );
+                # Load the correct fixer here, we have the data here
+                $fix_module = $cond->fix_module;
+          } catch {
+                $logger->fatal(sprintf('%s at [plugin_fixer_%s]', $_, $opt->{'fixer'}));
                 exit 1;
-            }
-            elsif (is_instance $_, 'Datahub::Factory::ModuleNotFound') {
-                # Throw a fatal error if we couldn't load a fix module
-                $logger->fatal($error);
-                exit 1;
-            }
-            else {
-                # Catmandu modules produce a wide variety of exceptions. This
-                # block catches them, but doesn't halt the processing entirely.
-                $logger->error($error);
-                $self->error($error);
-                return 1;
-            }
-        }) {
-            # skip to the next record if an error was raised.
-            return 1;
-        };
-    });
+          };
+
+          # Execute the fix
+          $fix_module->fixer->fix($item);
+      } catch {
+          my $error_msg;
+          if ($_->can('message')) {
+              $error_msg = sprintf('Item %d (counted): could not execute fix: %s', $counter, $_->message);
+          } else {
+              $error_msg = sprintf('Item %d (counted): could not execute fix: %s', $counter, $_);
+          }
+          $logger->error($error_msg);
+          return 1;
+      };
+      if (defined($f) && $f == 1) {
+          # End the processing of this record, go to the next one.
+          return;
+      }
+
+      my $item_id = data_at($opt->{'id_path'}, $item);
+      my $e = try {
+          $export_module->add($item);
+      } catch {
+          my $error_msg;
+          # $item_id can be undefined if it isn't set in the source, but this
+          # is only discovered when exporting (and not during fixing)
+          my $id_type = 'id';
+          if (!defined($item_id)) {
+              $item_id = $counter;
+              $id_type = 'counted';
+          }
+          if ($_->can('message')) {
+              $error_msg = sprintf('Item %s (%s): could not export item: %s', $item_id, $id_type, $_->message);
+          } else {
+              $error_msg = sprintf('Item %s (%s): could not export item: %s', $item_id, $id_type, $_);
+          }
+          $logger->error($error_msg);
+          return 1;
+      };
+
+      if (defined($e) && $e == 1) {
+          # End the processing of this record, go to the next one.
+          return;
+      }
+      $logger->info(sprintf('Item %s (id): exported.', $item_id));
+  });
+
 }
 
 1;
@@ -205,7 +210,6 @@ Supported I<Exporter> plugins:
 
     [Importer]
     plugin = OAI
-    id_path = 'lidoRecID.0._'
 
     [plugin_importer_OAI]
     endpoint = https://oai.my.museum/oai
@@ -215,11 +219,12 @@ Supported I<Exporter> plugins:
 
     [plugin_fixer_Fix]
     file_name = '/home/datahub/my.fix'
+    id_path = 'lidoRecID.0._'
 
     [Exporter]
-    plugin = YAML
+    plugin = LIDO
 
-    [plugin_exporter_YAML]
+    [plugin_exporter_LIDO]
 
 All plugins have their own configuration options in sections called
 C<[plugin_type_name]> where C<type> can be I<importer>, I<exporter>
@@ -233,20 +238,16 @@ If a plugin requires no options, you still need to create the (empty)
 configuration section (e.g. C<[plugin_exporter_LIDO]> in the above
 example).
 
-=head4 Importer plugin
-
-The C<id_path> option contains the path (in Fix syntax) of the identifier of
-each record in your data after the fix has been applied, but before it is
-submitted to the I<Exporter>. It is used for reporting and logging.
-
 =head4 Fixer plugin
 
     [plugin_fixer_Fix]
     condition = record.institution_name
-    fixers = FOO, BAR
+    fixers = MSK, GRO
+    id_path = record.id
 
     [plugin_fixer_Fix]
     file_name = /home/datahub/my.fix
+    id_path = record.id
 
 The C<[plugin_fixer_Fix]> can directly load a fix file (via the option
 C<file_name>) or can be configured to conditionally load a different
@@ -255,19 +256,26 @@ when two institutions with different data models use the same API
 endpoint). This is done by setting the C<condition> and C<fixers>
 options.
 
+The C<id_path> option contains the path (in Fix syntax) of the identifier of
+each record in your data after the fix has been applied, but before it is
+submitted to the I<Exporter>. It is used for reporting and logging.
+
 =head4 Conditional fixers
 
     [plugin_fixer_Fix]
     condition = record.institution_name
-    fixers = FOO, BAR
+    fixers = MSK, GRO
+    id_path = 'lidoRecID.0._'
 
-    [plugin_fixer_FOO]
-    condition = 'Museum of Foo'
-    file_name = '/home/datahub/foo.fix'
+    [plugin_fixer_GRO]
+    condition = 'Groeningemuseum'
+    file_name = '/home/datahub/gro.fix'
+    id_path = 'lidoRecID.0._'
 
-    [plugin_fixer_BAR]
-    condition = 'Museum of Bar'
-    file_name = '/home/datahub/bar.fix'
+    [plugin_fixer_MSK]
+    condition = 'Museum voor Schone Kunsten Gent'
+    file_name = '/home/datahub/msk.fix'
+    id_path = 'lidoRecID.0._'
 
 If you want to separate the data stream into multiple (smaller) streams with
 a different fix file for each stream, you can do this by setting the appropriate
@@ -293,13 +301,14 @@ the record to belong to this block.
 The location of the fix file that must be executed for every record in this
 block.
 
+=item C<id_path>
+
 =back
 
 =head4 Example configuration file
 
   [Importer]
   plugin = Adlib
-  id_path = 'record.id'
 
   [Fixer]
   plugin = Fix
@@ -313,6 +322,7 @@ block.
 
   [plugin_fixer_Fix]
   file_name = '/tmp/msk.fix'
+  id_path = 'record.id'
 
   [plugin_exporter_Datahub]
   datahub_url = https://my.thedatahub.io
@@ -325,6 +335,7 @@ block.
 =head1 AUTHORS
 
 Pieter De Praetere <pieter@packed.be>
+
 Matthias Vandermaesen <matthias.vandermaesen@vlaamsekunstcollectie.be>
 
 =head1 COPYRIGHT
