@@ -64,10 +64,13 @@ Datahub::Factory::Importer::CollectiveAccess - Import data from a L<CollectiveAc
 
 =head1 SYNOPSIS
 
-    use Datahub::Factory::Importer::CollectiveAccess;
+    use Datahub::Factory;
     use Data::Dumper qw(Dumper);
 
-    my $ca = Datahub::Factory::Importer::CollectiveAccess->new(
+    my $ca = Datahub::Factory->importer('CollectiveAccess')->new(
+		endpoint => 'https://my.ca.org/ca',
+		username => 'datahub',
+		password => 'datahub'
     );
 
     $ca->importer->each(sub {
@@ -84,6 +87,51 @@ from a  L<CollectiveAccess|http://collectiveaccess.org/> instance. It returns an
 
 =over
 
+=item C<endpoint>
+
+URL of the CA instance (e.g. I<http://demo.collectiveaccess.org>).
+
+=item C<username>
+
+Name of a user that can be used to query the API.
+
+=item C<password>
+
+Password for the user.
+
+=item C<field_list>
+
+A list of fields that the CollectiveAccess API should return.
+Is optional and can be left empty to return the default:
+
+	[
+		'ca_objects.object_id',
+		'ca_objects.preferred_labels',
+		'ca_objects.description',
+		'ca_objects.subtitle',
+		'ca_objects.geonames',
+		'ca_objects.lcsh_terms',
+		'ca_objects.colour',
+		'ca_objects.contentActivity',
+		'ca_objects.contentConcept',
+		'ca_objects.contentDescription',
+		'ca_objects.dimensions.dimensions_width',
+		'ca_objects.dimensions.dimensions_height',
+		'ca_objects.dimensions.dimensions_depth',
+		'ca_objects.dimensions.circumference',
+		'ca_objects.dimensions.dimensions_type',
+		'ca_objects.materialInfo.materialInfostyle',
+		'ca_objects.objectProductionDate',
+		'ca_objects.techniqueInfo.techniqueInfodatePeriod',
+		'ca_objects.dateText',
+		'ca_objects.objectName.objectObjectName',
+		'ca_objects.objectWorkPid.objectWorkPidDomain',
+		'ca_objects.objectWorkPid.objectWorkPidID',
+		'ca_objects.objectRecordPid.objectRecordPidDomain',
+		'ca_objects.objectRecordPid.objectRecordPidID',
+		'ca_entities.entity_id',
+		'ca_entities.relationship_type_code'
+    ]
 
 =back
 
